import React, { createContext, useContext, useRef, useCallback } from 'react';
import cn from 'classnames';
import { RemoveScrollBar } from 'react-remove-scroll-bar';
import { useTheme } from '@rescui/ui-contexts';
import styles from './sidebar.module.css.js';
const SidebarContext = createContext({});

function useSidebarContext() {
  return useContext(SidebarContext);
}

function Sidebar({
  className,
  classNameContent,
  mode,
  children,
  isOpen,
  onClose
}) {
  const ref = useRef(null);
  const theme = useTheme();
  const onToggleClick = useCallback(e => {
    if (e.currentTarget == e.target) onClose();
  }, [onClose]);
  const classes = cn(className, styles.popup, styles[theme || 'light'], {
    [styles.close]: !isOpen,
    [styles[`${mode}Mode`]]: Boolean(mode && styles[`${mode}Mode`])
  });
  const disableProps = {};

  if (!isOpen) {
    disableProps.tabIndex = -1;
    disableProps.role = 'none';
  }

  return React.createElement(SidebarContext.Provider, {
    value: {
      onClose
    }
  }, React.createElement("div", {
    className: classes,
    onClick: onToggleClick,
    ...disableProps
  }, isOpen && React.createElement(RemoveScrollBar, null), React.createElement("div", {
    ref: ref,
    className: cn(classNameContent, styles.content)
  }, children)));
}

export { Sidebar, SidebarContext, useSidebarContext };
